%Archsc
%Archsc gives us the matrix Sc of the different evolutions of the architectures submitted to several demand scenarios (Demand matrix)
%path is a row vector containing the indices of the architectures in the path [i1, i2, i3].
%cost gives the costs for each "capacity" scenarios
%finally, Pr is the probability of each scenario and is given with the demand scenarios (matrix P)

%%%%%%%%%%%%%%%%%%%%% NOTE: path may be a vector containing the mass and volume information for each architecture %%%%%%%%%%%%%%%%%%

function [Sc,cost,Pr,NPV,flag]=archsc(path,Capm,D,Demand,P,IDC,OSC,deltac,XM,XV,x_all,c,r,p,dr)
%dr is the discount rate
per=D.period;
T=D.totaltime;
t=D.tstep;
D0=D.initial;
np=length(path);
[nd,md]=size(Demand);
Sc=[];
%1/ We create a row vector Cap with the capacities of the different architectures along the path
Cap=[];
for i=1:np
    Cap=[Cap Capm(path(i))];
end
Cap;
%2/ We generate the scenarios for capacity

flag=0; %Flag is a variable equal to 1 if there is a scenario for which we cannot adapt to demand (Demand goes over our Max Cap), 0 otherwise.
for k=1:nd %We look at each demand scenario
    iarch=1;%iarch keeps track of the rank of the current architecture on the path
    Carch=Cap(iarch);%arch is the capacity of this architecture
    Sd=Demand(k,:);
    S=[path(iarch)*ones(1,t)]; %S is a vector that we build an that gives the number of the architecture for each year
    for l=1:(per-1)
        if Carch<Sd(l)
            if iarch+1>np %We cannot move to a higher capacity and demand cannot be assesed so flag=1
                flag=1;
                Carch=Cap(iarch);
            else
            iarch=iarch+1; %We need to move to a higher capacity and change our architecture.
            Carch=Cap(iarch);
            end
        else
        end
        S=[S path(iarch)*ones(1,t)];
    end
    Sc=[Sc;S];
end

Pr=P;       

%3/ We now need to create a module that calculates the cost for a series of architecture and the average value.

%We generate a series of cost for each capacity scenario: matrix cost

%a) Create a matrix with for each path the calculated deployment cost or transition cost plus maintenance costs.
%b) Simplify the way the maintenance and deployment costs are calculated as well as transition costs.
%c) Include the NPV calculations. See how to take extra volume and extra mass into account

%To save time, vectors IDC and OSC are calculated in advance for each constellations. (cf. GenLCC_new)

%Matrix Costpath keeps track of the Initial deployment cost and upgrade cost on the first row and maintenance costs for each architecture on the second row.
Costpath=[IDC(1,path(1));OSC(1,path(1))];
if np>1
    for i=2:np
        upgrade=deltac(path(i-1),path(i)); %We assume that each transition carries same weigth and volume for sats.
        Costpath=[Costpath [upgrade;OSC(1,path(i))]];
    end
else
end

ucash=[sum(Costpath(:,1))]; %All of the rows of Scash start with ucash as a first entry
Scash=[]; NPV=[];
for i=1:nd
    arch=1;
    index=Sc(i,1);  
    X=[ucash];
    for k=2:T
        if index~=Sc(i,k)
            arch=arch+1;
            index=Sc(i,k);
            X=[X sum(Costpath(:,arch))];
        else
            X=[X Costpath(2,arch)];
        end
    end
    Scash=[Scash; X];
    NPV=[NPV; pvvar(X,dr)];
end
cost=sum(NPV.*P);