%We try to create a faster program to generate the binomial demand tree.
%The outputs are the following:
% - S is the matrix containind the evolution on the binomial tree that is to say the up and down movements
% - demand gives us the actual evolution of the value of demand for each path in the tree
% - P is a column vector with the probability of each path
% As an input, we should have the structure for demand D, generated with GenD


function [S,demand,P]=binotree(D);
u=D.up; d=D.down; n=D.period; S=[]; P=[ones(2^n,1)]; D0=D.initial;
p=D.p;

for i=1:n
    A=[u*ones(1,2^(n-i)) d*ones(1,2^(n-i))]'; %A is a subcolumn [u;u;...;u;d;d;....;d]
    prob=[p*ones(1,2^(n-i)) (1-p)*ones(1,2^(n-i))]'; %prob is the associated probability;
    V=[]; U=[];
    %We generate the i-th column of S and U is the associated probability
    for k=1:2^(i-1)
        V=[V;A];
        U=[U;prob];
    end
    
    S=[S V];
    P=P.*U;
end

demand=[D0*S(:,1)];
for i=2:n
    demand=[demand S(:,i).*demand(:,i-1)];
end
