%This module is gives the extra cost to go from one architecture to the other.
%It is based on Darrens module.
%i1 and i2 are the indices of our architectures in our databases. We go from i1 to i2

function Delta = delta_cost(i1,i2,x_all,Capm,c,r,p,I_all)
Tanc=ancestors(i1,x_all,Capm);
%We check if i2 is a constellation that i1 can reach
[ntanc,mtanc]=size(Tanc);
stop=0; %stop=1 if i2 is one of the higher capacity constellations
for j=2:mtanc
        if Tanc(2,j)==i2&Tanc(3,j)<=Tanc(3,1)&Tanc(4,j)>=Tanc(4,1)
        stop=1;
        break
         else
        end
end


if stop==0
    Delta=0; %This transition is impossible
else
Y1=x_all(i1);
Y2=x_all(i2);
I1=I_all(i1);
I2=I_all(i2);

%% Cost of manufacturing new satellites
% 1/ Find number of sats to build
extraN =I2.Nsats+I2.Nplanes-(I1.Nsats+I1.Nplanes);		% extra number of sats to build
if extraN<=0;
    Prod_cost=0; %It is not necessary to build new satellites.
    UHC=[0];
else
    
    if I2.Nsats+I2.Nplanes< 1
    LCS = 95;
    elseif 10 <= (I2.Nsats+I2.Nplanes) & (I2.Nsats+I2.Nplanes) <=50
    LCS = 90;
    else
    LCS = 85;
    end;

    % 2/find the hardware cost of each unit knowing that similar sats have already been built
    TFUHC=I1.TFUHC; %Price of the first satellite manufactured
    B = 1 - log(100/LCS)/log(2);
    previousCost = I1.Lastsat_cost;
    for i = 1:extraN;
    LCF = (i+(I1.Nsats+I1.Nplanes))^B;	% learning curve factor
    UHC(i) = TFUHC*LCF - previousCost;
    previousCost = TFUHC*LCF;
    end;
    UHC(extraN);
    I2.Lastsat_cost;

    % 3/ When the orbit altitude reaches 650km, hardening is needed to protect the s/c 
    % from Van Allen belts
    if Y2.r >= 650
        UHC = UHC*1.05;
    else
    end
end

%5/find Launch Operations and Orbit Support Cost for all units in FY2002$K (The extra mass is not taken into account)
if I2.AKM == 0
   LOOSC = 2.51*I2.Msat;
else
   LOOSC = 64 + 1.44*I2.Msat;
end;
totLOOSC = LOOSC*extraN*0.8*1.369;

%6/find Launch Vehicle Cost in FY2002$K
[launchVehicle_best,LVModelFileName_best,satPerVehicle_best,...
      numberOfLaunch_best,launchSite_best,LPModelFileName_best,...
      LSla_best,LSlo_best,LSR_best,minLaunchCost,LScounter,...
      costPerLaunchl_best,costPerLaunchh_best,burnoutVelocity_best]...
   = LV(I2.Msat,I2.Vsat,pi/2,extraN,Y2.r);
LVC = minLaunchCost;

%7/find total Ground Segment Development Cost in FY2002$K
GSDC = (18 + 81 + 100 + 15 + 18 + 30 + 15 + 24)/100*(I2.NGS-I1.NGS);
%8/find Upgrade Cost in FY2002$K
IDC = sum(UHC) + totLOOSC + GSDC + LVC;
Delta=IDC;
end
