function [I,Iunits]=run(xv,cv,rv,pv,XM,XV);
% run

% run is an adptation of run_LEO to get only the information that are useful for our calculations of capacity and costs

% inputs and have been modified and all of the information is gathered in a structure I with Iunits associated.

% Functions that are used may have been modified to bring other outputs (in this case they are renamed with a w at the end)

% XM is an extramass necessary for reconfigurations on a satellite.
C=xv.C;
r=xv.r;
epsilon=xv.epsilon;
Pt=xv.Pt;
DA=xv.DA;
Dfc=xv.Dfc;
ISL=xv.ISL;
Tsat=xv.Tsat;

MS=cv.MS;
Pe=cv.Pe;
MAM=cv.MAM;
Ge=cv.Ge;
incli=cv.incli;
eta_t=cv.eta_t;
DR=cv.DR;
GB=cv.GB;

BER=rv.BER;
R=rv.R;
margin=rv.margin;

Fms_link_lb=pv.Fms_downlink_lb;
Fms_link_ub=pv.Fms_downlink_ub;

% execute N2 Diagram in sequence

% TECHNICAL MACRO-MODULE

% 1. coverage module

alti=r;   % desired orbital altitude [km]

elev=(pi/180)*epsilon;   % elevation angle [rad]

constel=1; %We only consider polar constellations

% 1. coverage module
[slantRange,dist,incli,Nmin,NSmin,NPmin,orbitR,delta,central,period] = ...
   coverage(constel,alti,elev,incli);

% 2. network module
xlink=ISL;
[GSKLOC,NGS,personnel] = satNetwork(constel,xlink,Nmin,NPmin);


% 3. spacecraft module

powerSat=Pt;  % assume sat power = transmit power
DSatT=DA; %antenna Diameter
DSatR=DSatT;
[Msat,Vsat,AntW,CEW,SCBDW,BLP,AKM,AKMDW,FSKLOC,totImpulse] = ...
   spacecraftw(powerSat,DSatT,DSatR,xlink,GSKLOC);

% 4. launch vehicle module

[launchVehicle_best,LVModelFileName_best,satPerVehicle_best,...
      numberOfLaunch_best,launchSite_best,LPModelFileName_best,...
      LSla_best,LSlo_best,LSR_best,minLaunchCost,LScounter,...
      costPerLaunchl_best,costPerLaunchh_best,burnoutVelocity_best]...
   = LV(Msat+XM,Vsat+XV,incli,Nmin,alti);

  
 % 5. cost module
       spaceLife=ceil(Tsat);
       IDTime=Tsat;
       [ID_cost,maint_cost,Lastsat_cost,TFUHC] = costw(Nmin,NPmin,alti,AntW,...
       CEW,SCBDW,Msat,BLP,FSKLOC,GSKLOC,spaceLife,IDTime,NGS,personnel,...
       AKM,AKMDW,totImpulse,DR,minLaunchCost);
    
    % Creation of the I structure
    
    % 1/From coverage module
    I.Nsats=Nmin;
    I.Nplanes=NPmin;
    I.NSP=NSmin;
    
    % 2/From network module
    I.GSKLOC=GSKLOC;
    I.NGS=NGS;
    I.personnel=personnel;
    
    % 3/From spacecraft module
    
    I.Msat=Msat;        % spacecraft mass in kg without the extra mass XM
    I.XM=XM;            % Extra mass on the satellite for reconfiguration
    I.Vsat=Vsat;	    % spacecraft volume in m^3, estimated from existing systems
    I.XV=XV;            % Extra volume for the propulsion system
    I.CEW=CEW;		    % communication electronics weight in kg, estimatd from existing systems
    I.SCBDW=SCBDW;      % spacecraft bus dry weight in kg, estimatd from existing systems
    I.AKM=AKM;			% type of apogee kick motor.  0 for no AKM, 1 for spin-stablized and 2 for 3-axis-stablized
    I.AKMDW	= AKMDW;      % AKM dry weight in kg
    I.FSKLOC= FSKLOC;   % flight software thousand lines of code
    
    % 4/ From launch vehicle module
    I.minLaunchCost=minLaunchCost;
    
    %5/ From cost module
    I.ID_cost=ID_cost;
    I.maint_cost=maint_cost;
    I.Lastsat_cost=Lastsat_cost;
    I.TFUHC=TFUHC;
       
    %Creation of the Iunits vector
    Iunits.Nsats='[# of sats]';
    Iunits.Nplanes='[# of planes]';
    Iunits.NSP='[# of sats per planes]';
    Iunits.GSKLOC='[ground system thousand lines of code]';
    Iunits.NGS=NGS; '[# of ground systems]';
    Iunits.personnel=personnel; '[total # of ground stations employees]';
    Iunits.Msat=['spacecraft mass without extra mass in kg'];
    Iunits.XM=['Extra mass in kg'];
    Iunits.Vsat=['spacecraft volume without extra volume in m^3'];
    Iunits.XV=['Extra volume in m^3'];
    Iunits.CEW=['Comm. electronics weigth in kg'];
    Iunits.SCBDW=['Spacecraft dry bus weigth in kg'];
    Iunits.AKM=['Apogee kick motor. 0: no AKM, 1: spin-stab, 2: 3-axis'];
    Iunits.AKMDW=['AKM dry weigth in kg'];
    Iunits.FSKLOC=['Fligth software thousand lines of codes'];
    Iunits.minLaunchCost=['$K'];
    Iunits.ID_cost=['Initial deployment cost in $K'];
    Iunits.maint_cost=['Maintenance cost per year in $K'];
    Iunits.Lastsat_cost=['Price of the last satellite built in $K'];
    Iunits.TFUHC=['Price of the first satellite [$K]'];