function [nondom,dom,dmatrix]=paretosort(Jall,minmax);
% Algorithm for finding non-dominated solutions from
% a set of solutions in objective space J.
% Inputs:
% Jall - matrix with z-rows containing the objective
%        values and n-columns containing columnwise
%        solutions
% minmax - vector of length zx1. A -1 in the j-th row 
%          indicates that the j-th objective is to be 
%          minimized, a 1 indicates that the j-th objective
%          is to be maximized
% Outputs:
% nondom  - vector of indices into the columns of Jall
%           indicating the non-dominated solutions
% dom     - 1xn vector containing the number of solutions
%           that dominate a particular solution, a 0 indicates
%           a non-dominated solution
% dmatrix - is the nxn domination matrix 
% (c) dWo, MIT, 27 March 2002

n=size(Jall,2);
z=size(Jall,1);
indx=1;
dmatrix=zeros(n,n);

for ind1=1:(n-1)
   
   for ind2=(ind1+1):n
      
      Ja=Jall(:,ind1).*sign(minmax);
      Jb=Jall(:,ind2).*sign(minmax);
      
      scorea=0;
      scoreb=0;
      
      for indz=1:z
         if Ja(indz)>Jb(indz)
            scorea=scorea+1;
         elseif Ja(indz)<Jb(indz)
            scoreb=scoreb+1;
         else
            % both solutions are equal
         end
      end
      if scoreb==0&scorea~=0
         dmatrix(ind1,ind2)=1; %a dominates b
      elseif scorea==0&scoreb~=0
         dmatrix(ind2,ind1)=1; %b dominates a
      else
         % no domination in this pair
      end
      
   end
end

   ind_dominates=sum(dmatrix');
   ind_dominated=sum(dmatrix);
   
   nondom=find(ind_dominated==0);
   dom=ind_dominated;
   
         
         
         
   


      