function [slantRange,dist,incli,Nmin,NSmin,NPmin,orbitR,delta,central,period] = ...
          coverage(constel,alti,elev,incli);
% Program that calculates coverage geometry for different LEO constellations
% Darren Zhang (darrenz@mit.edu)
% Last modified by 3/17/02

% This program calculates orbit plane number and
% number of sats. per plane that will provide the
% minimum total amount of sats. for a global coverage
% at given satellite constellation type, altitude,
% and elevation angle.  The calculation can
% be done either for Walker constellation or Polar
% constellation.

% The equations for Polar constellation are based on Chapter 2 and 3 in LWJ00.

% Unless followed by _d, otherwise all angles are in radian.

% orbitR   - earth-centered sat. radius (km)
% Dsat     - satellite antenna diameter (m)
% freq     - frequency (Hz)
% aperture - aperture type (1 for tapered and 2 for uniform)
% constel  - constellation type (1 for polar and 2 for Walker)
% elev     - elevation angle
% N		  - number of satellites in constellation
% NS		  - number of satellites per plane
% NP		  - number of planes

% problems yet to be solved
% 1. Need to work out Walker Constellation part.
%			[km			 ,rad,#   ,#    ,#    ,km]                             (		 ,km,  rad)

Rearth   = 6371;  % Earth average radius in km
Nmin = 10000; 		% set Nmin to a large number

orbitR     = alti + Rearth;

% polar constellation
if constel == 1				
   incli = pi/2;												% inclination angle
   
   nadir = asin(Rearth/orbitR*cos(elev));					% nadir angle in radian, eqn (2.24)
   
   central = asin(orbitR/Rearth*sin(nadir)) - nadir;	% earth central angle in radian, eqn (2.23)

   for NP = 1:1000												% try up to 100 planes
      tmp = (pi - (NP - 1)*central)/(NP + 1);
      if cos(central) > cos(tmp)							% if there are not enough planes to provide global coverage, then do nothing
          ;
      else
         NS = ceil(pi/acos(cos(central)/cos((pi - (NP - 1)*central)/(NP + 1))));
         N = NS*NP;
         if N < Nmin
            Nmin  = N;			% minimum number of satellites in constellation
            NSmin = NS;			% minimum number of satellites per plane
            NPmin = NP;			% minimum number of planes
         else
            ;
         end; %end if
      end; %end if
   end; %end for
   delta = acos(cos(central)/cos(pi/NSmin));         % delta in radian, eqn (2.39)

% Walker constellation
elseif constel == 2
   ;
else
   ;
end;

Afoot  = 2*pi*Rearth^2*(1 - cos(central));					% footprint area in km^2, eqn (2.31)
slantRange = sqrt(Rearth^2 + orbitR^2 - 2*Rearth*orbitR*cos(central));	% slant range in km, eqn (2.26)
dist = (slantRange + alti)/2;

%fprintf('The outputs are\n');
%fprintf('Number of satillites in the constellation = %10.0f\n',Nmin);
%fprintf('Number of planes = %10.0f\n',NPmin);
%fprintf('Number of satellites per plane = %10.0f\n',NSmin);
%fprintf('Footprint area in squre km = %10.2f\n',Afoot);
%fprintf('Slant range (max ground-sat. distance) = %10.2f\n',slantRange);
GMearth=398601;
period=2*pi*sqrt((orbitR)^3/GMearth)/60;   %orbital period in minutes

