% input1.m
% It reads constant parameters and design variables from text files.
% If the text files don't exist, then the program
% asks inputs from the user.

% last modified on 4/1/02
% by Darren Chang (darrenz@mit.edu)

FID_Input = fopen(constant_file, 'r');

if FID_Input == -1
    % Ask inputs from user if FID is -1.
    fprintf('Input the following constants (They will stay constant throughout the program):\n\n');
    EffT = input('\nefficiency of all transmitters in percentage = ');	% percentage
    EffR = input('\nefficiency of all receivers in percentage = ');		% percentage
    BERTotal = input('\ntotal bit error rate along the link = ');		% bit/bit
    DR = input('\ndiscount rate in percentage = ');								% percentage
    powerUser = input('\nuser termianl power (W) = ');							% Watt
    DUser = input('\nuser termianl diameter (m) = ');							% meter
    userBW = input('\nuser bandwidth (kbps) = ');                           % kbps
    freqUS = input('\nuser to satellite frequency (GHz) = ');				% GHz
    freqSU = input('\nsatellite to user frequency (GHz) = ');				% GHz
    freqGS = input('\nground station to satellite frequency (GHz) = ');	% GHz
    freqSG = input('\nsatellite to ground station frequency (GHz) = ');	% GHz
    freqSS = input('\nsatellite to satellite crosslink frequency (GHz) = '); % GHz
    IDTime = input('\ninitial deployment time (years) = ');					% year
    spaceLife = input('\nspace life of the system (years) = ');				% year
    marketSize = input('\nmarket demand (number of people) = ');            % number of people
else
    % Otherwise proceed.
    
    % Skip the first line
    linechar = fgetl(FID_Input);
    
    linechar = fgetl(FID_Input);
    EffT = sscanf(linechar, 'efficiency of all transmitters in percentage = %f');
    
    linechar = fgetl(FID_Input);
    EffR = sscanf(linechar, 'efficiency of all receivers in percentage = %f');
    
    linechar = fgetl(FID_Input);
    BERTotal = sscanf(linechar, 'total bit error rate along the link = %f');
    
    linechar = fgetl(FID_Input);
    DR = sscanf(linechar, 'discount rate in percentage = %f');
    
    linechar = fgetl(FID_Input);
    powerUser = sscanf(linechar, 'user termianl power (W) = %f');
    
    linechar = fgetl(FID_Input);
    DUser = sscanf(linechar, 'user termianl diameter (m) = %f');
    
    linechar = fgetl(FID_Input);
    userBW = sscanf(linechar, 'user bandwidth (kbps) = %f');
    
    linechar = fgetl(FID_Input);
    freqUS = sscanf(linechar, 'user to satellite frequency (GHz) = %f');
    
    linechar = fgetl(FID_Input);
    freqSU = sscanf(linechar, 'satellite to user frequency (GHz) = %f');
    
    linechar = fgetl(FID_Input);
    freqGS = sscanf(linechar, 'ground station to satellite frequency (GHz) = %f');
    
    linechar = fgetl(FID_Input);
    freqSG = sscanf(linechar, 'satellite to ground station frequency (GHz) = %f');
    
    linechar = fgetl(FID_Input);
    freqSS = sscanf(linechar, 'satellite to satellite crosslink frequency (GHz) = %f');
    
    linechar = fgetl(FID_Input);
    IDTime = sscanf(linechar, 'initial deployment time (years) = %f');
    
    linechar = fgetl(FID_Input);
    spaceLife = sscanf(linechar, 'space life of the system (years) = %f');
    
    linechar = fgetl(FID_Input);
    marketSize = sscanf(linechar, 'market demand (number of people) = %f');
end
% Close the file
fclose(FID_Input);

FID_Input = fopen(designVar_file, 'r');

if FID_Input == -1
    % Ask inputs from user if FID is -1.
    fprintf('\nInput the upper and lower limits of the design variables,\n');
	fprintf('and number of data points between the limits.\n\n');

	constel   = 1;	% when the Walker part is done, constel = [1,2]
	constel_n = 1;

	alti_l   = input('Enter lower orbit altitude of the satellite in kilometer: ');		% km
	alti_u   = input('Enter upper orbit altitude of the satellite in kilometer: ');		% km
	alti_n	= input('Enter number of data points between the lower and upper altitudes: ');
	alti		= linspace(alti_l,alti_u,alti_n);

	elev_l	= pi/180*input('\nEnter lower minimum elevation angle in degrees: ');			% radian
	elev_u	= pi/180*input('Enter upper minimum elevation angle in degrees: ');			% radian
	elev_n	= input('Enter number of data points between the lower and upper elevation angles: ');
	elev		= linspace(elev_l,elev_u,elev_n);

	powerSat_l	= input('\nEnter lower satellite transmitter power in Watts: ');			% Watts
	powerSat_u	= input('Enter upper satellite transmitter power in Watts: ');			% Watts
	powerSat_n	= input('Enter number of data points between the lower and upper powers: ');
	powerSat		= linspace(powerSat_l,powerSat_u,powerSat_n);

	DSatR_l	= input('\nEnter lower satellite receiver antenna diameter in meters: ');			% meters
	DSatR_u	= input('Enter upper satellite receiver antenna diameter in meters: ');			% meters
	DSatR_n	= input('Enter number of data points between the lower and upper diameters: ');
	DSatR		= linspace(DSatR_l,DSatR_u,DSatR_n);

	DSatT_l	= input('\nEnter lower satellite transmitter antenna diameter in meters: ');			% meters
	DSatT_u	= input('Enter upper satellite transmitter antenna diameter in meters: ');			% meters
	DSatT_n	= input('Enter number of data points between the lower and upper diameters: ');
	DSatT		= linspace(DSatT_l,DSatT_u,DSatT_n);
    
    %xlink = input('\nEnter 1 if satellites have crosslinks and 0 for NO crosslinks: ');

	powerGS_l	= input('\nEnter lower ground station transmitter power in Watts: ');			% Watts
	powerGS_u	= input('Enter upper ground station transmitter power in Watts: ');			% Watts
	powerGS_n	= input('Enter number of data points between the lower and upper powers: ');
	powerGS		= linspace(powerGS_l,powerGS_u,powerGS_n);

	DGSR_l	= input('\nEnter lower ground station receiver antenna diameter in meters: ');			% meters
	DGSR_u	= input('Enter upper ground station receiver antenna diameter in meters: ');			% meters
	DGSR_n	= input('Enter number of data points between the lower and upper diameters: ');
	DGSR		= linspace(DGSR_l,DGSR_u,DGSR_n);

	DGST_l	= input('\nEnter lower ground station transmitter antenna diameter in meters: ');		% meters
	DGST_u	= input('Enter upper ground station transmitter antenna diameter in meters: ');		% meters
	DGST_n	= input('Enter number of data points between the lower and upper diameters: ');
    DGST		= linspace(DGST_l,DGST_u,DGST_n);
else
    % Otherwise proceed.
    
    constel   = 1;	% when the Walker part is done, constel = [1,2]
	constel_n = 1;
    
    % Skip the first line
    linechar = fgetl(FID_Input);
    
    linechar = fgetl(FID_Input);
    alti_l = sscanf(linechar, 'Enter lower orbit altitude of the satellite in kilometer: %f');
    linechar = fgetl(FID_Input);
    alti_u = sscanf(linechar, 'Enter upper orbit altitude of the satellite in kilometer: %f');
    linechar = fgetl(FID_Input);
    alti_n = sscanf(linechar, 'Enter number of data points between the lower and upper altitudes: %f');
    alti		= linspace(alti_l,alti_u,alti_n);
    
    linechar = fgetl(FID_Input);
    linechar = fgetl(FID_Input);
    elev_l	= pi/180*sscanf(linechar, 'Enter lower minimum elevation angle in degrees: %f');
    linechar = fgetl(FID_Input);
    elev_u	= pi/180*sscanf(linechar, 'Enter upper minimum elevation angle in degrees: %f');
    linechar = fgetl(FID_Input);
    elev_n = sscanf(linechar, 'Enter number of data points between the lower and upper elevation angles: %f');
    elev		= linspace(elev_l,elev_u,elev_n);
    
    linechar = fgetl(FID_Input);
    linechar = fgetl(FID_Input);
    powerSat_l = sscanf(linechar, 'Enter lower satellite transmitter power in Watts: %f');
    linechar = fgetl(FID_Input);
    powerSat_u = sscanf(linechar, 'Enter upper satellite transmitter power in Watts: %f');
    linechar = fgetl(FID_Input);
    powerSat_n = sscanf(linechar, 'Enter number of data points between the lower and upper powers: %f');
    powerSat		= linspace(powerSat_l,powerSat_u,powerSat_n);
    
    linechar = fgetl(FID_Input);
    linechar = fgetl(FID_Input);
    DSatR_l = sscanf(linechar, 'Enter lower satellite receiver antenna diameter in meters: %f');
    linechar = fgetl(FID_Input);
    DSatR_u = sscanf(linechar, 'Enter upper satellite receiver antenna diameter in meters: %f');
    linechar = fgetl(FID_Input);
    DSatR_n = sscanf(linechar, 'Enter number of data points between the lower and upper diameters: %f');
    DSatR		= linspace(DSatR_l,DSatR_u,DSatR_n);
    
    linechar = fgetl(FID_Input);
    linechar = fgetl(FID_Input);
    DSatT_l	= sscanf(linechar, 'Enter lower satellite transmitter antenna diameter in meters: %f');			% meters
    linechar = fgetl(FID_Input);
	DSatT_u	= sscanf(linechar, 'Enter upper satellite transmitter antenna diameter in meters: %f');			% meters
    linechar = fgetl(FID_Input);
	DSatT_n	= sscanf(linechar, 'Enter number of data points between the lower and upper diameters: %f');
	DSatT		= linspace(DSatT_l,DSatT_u,DSatT_n);
    
    linechar = fgetl(FID_Input);
    linechar = fgetl(FID_Input);
    powerGS_l	= sscanf(linechar, 'Enter lower ground station transmitter power in Watts: %f');			% Watts
    linechar = fgetl(FID_Input);
	powerGS_u	= sscanf(linechar, 'Enter upper ground station transmitter power in Watts: %f');			% Watts
    linechar = fgetl(FID_Input);
	powerGS_n	= sscanf(linechar, 'Enter number of data points between the lower and upper powers: %f');
	powerGS		= linspace(powerGS_l,powerGS_u,powerGS_n);

    linechar = fgetl(FID_Input);
    linechar = fgetl(FID_Input);
	DGSR_l	= sscanf(linechar, 'Enter lower ground station receiver antenna diameter in meters: %f');			% meters
    linechar = fgetl(FID_Input);
	DGSR_u	= sscanf(linechar, 'Enter upper ground station receiver antenna diameter in meters: %f');			% meters
    linechar = fgetl(FID_Input);
	DGSR_n	= sscanf(linechar, 'Enter number of data points between the lower and upper diameters: %f');
	DGSR		= linspace(DGSR_l,DGSR_u,DGSR_n);

    linechar = fgetl(FID_Input);
    linechar = fgetl(FID_Input);
	DGST_l	= sscanf(linechar, 'Enter lower ground station transmitter antenna diameter in meters: %f');		% meters
    linechar = fgetl(FID_Input);
	DGST_u	= sscanf(linechar, 'Enter upper ground station transmitter antenna diameter in meters: %f');		% meters
    linechar = fgetl(FID_Input);
	DGST_n	= sscanf(linechar, 'Enter number of data points between the lower and upper diameters: %f');
    DGST		= linspace(DGST_l,DGST_u,DGST_n);
end
% Close the file
fclose(FID_Input);



