 function          [userPerSat,delaymin,delaymax,avEIRP,PFD,Gt,beamwidthT,nochannels] = linkDesign(freqSU,BWspectrum,Dfc,GB,powerSat,DSatT,GR_dB,...
           EffT,EffR,slantRange,alti,UpDownX,BER,userBW,margin,MS);
        
        
% function linkDesign
% Module that computes capability per satellite (user/sat)
% based on link budget of a route

% Darren Chang (darrenz@mit.edu)
% Last modified by 3/20/02

% problems yet to be solved
% 1. find the right range b/w the satellite - satellite link.  It's not slantRange.
% 2. estimate the max. antenna pointing offset angle of transmitter.
% 3. estimate atmospheric loss using ITU-R P676-4
% 4. find out how to calculate beamwidth for PHASED-ARRAY ANTENNA


% Step 1: select carrier frequency.
% This is for either the uplink or downlink,
% user or feeder.
% The frequency is allocated by FCC,
% and therefore a constant variable.

freq=freqSU;
DT= DSatT;
dist=alti;
slantRange;
power=powerSat;

% Step 2: select the transmitter power.
% If satellite transmitter, it's a design variable.
% If ground station transmitter or user terminal transmitter,
% then they are constant varaibles for now.

% Step 3: rf loss b/w transmitter and antenna is picked arbitrarily

Ll_dB = -2;		% dB

% Step 4: find the beamwidth of tranmitter antenna
% still need to find out how to calculate
% beamwidth for PHASED-ARRAY ANTENNA

beamwidthT = 21/freq/DT;    % deg

% Step 5: estimate the max. antenna pointing 
% offset angle of transmitter. HOW?
% And find reduction in peak gain caused by 
% a pointing offset from beam center for transmitter
% eqn (13-19)

eT = 0.1;				% deg
LoffsetT_dB = -12*(eT/beamwidthT)^2;	% dB

% Step 6: caulculate transmitter antenna gain, eqn (13-18)

GT_dB = 44.3 - 10*log(beamwidthT^2)/log(10) + 10*log(EffT/55)/log(10);	% dB

% Step 7: calculate space loss
% dist in m

%Lspace_dB = 147.55 - 20*log(dist*1000)/log(10) - 20*log(freq*1e9)/log(10);		% dB
Lspace_dB = 147.55 - 20*log(0.5*(slantRange+dist)*1000)/log(10) - 20*log(freq*1e9)/log(10);		% dB

% Step 8: estimate atmospheric loss using ITU-R P676-4

La_dB = -2;	   	% temporary, dB
Lpolar_dB = -0.3;	% polarization mismatch loss, dB
Lradom_dB = -1;	% radome loss, dB

% Step 9: estimate pointing offset angle
% of receiver and find the loss caused
% by this offset

% assume auto tracking is used
DR=0.1;
beamwidthR = 21/freq/DR;	% deg
eR = 0.1*beamwidthR;
LoffsetR_dB = -12*(eR/beamwidthR)^2;	% dB

% Step 10: find receiver antenna gain
%if 0
%GR_dB = -159.59 + 20*log(DR)/log(10) + 20*log(freq*1e9)/log(10) + 10*log(EffR/100)/log(10);	% dB
%else
   GR_dB=0;  % assume non-directional end-user antenna per Ray Leopold discussion
%end

% Step 11: estimate system noise
if UpDownX == 2				% downlink
   if freq < 2				% GHz
      Tnoise_dBK = 25.7;	% dB-K
   elseif 2 <= freq & freq <= 12
      Tnoise_dBK = 27.4;
   else
      Tnoise_dBK = 28.6;
   end;
elseif UpDownX == 3			% crosslink
   Tnoise_dBK = 32.5;
elseif UpDownX == 1			% uplink
   if freq < 20
      Tnoise_dBK = 31.1;
   else
      Tnoise_dBK = 32.6;
   end;
else					
   Tnoise_dBK = 0;
end;

% Step 12: find Eb/No
% assume 95% confidence, worst case, BPSK
k = 2;

BEP  = BER + k*sqrt(BER);

% 
% EbNo = (erfinv(1 - 2*BEP))^2;   % This gives unrealistically low EbNo
% find EbNo via interpolation function
if strcmp(MS,'QPSK')
   EbNo_dB=interp1([1e-7 1e-6 1e-5 1e-4 1e-3 1e-2 1e-1],[11.2 10.5 9.5 8.25 7 4.2 0.25],BER);
else
   disp('no code')
end

%EbNo_dB = 10*log(EbNo)/log(10);

% Step 13: add implementation loss and margin and calculate total data rate of a sat.

Limp = -2;  % dB
%margin = 3; % dB

dataRate_dB = 10*log(power)/log(10) + Ll_dB + GT_dB + LoffsetT_dB + Lspace_dB + La_dB + Lpolar_dB + Lradom_dB + LoffsetR_dB + GR_dB + 228.6 + Limp - Tnoise_dBK - EbNo_dB - margin;
dataRate = 10^(0.1*dataRate_dB)/1000;    % kbps

userPerSat = dataRate/userBW;

delaymin=dist/3e5;
delaymax=slantRange/3e5;

avEIRP=GT_dB+10*log10(power);

PFD=power/(0.5*(dist+slantRange)*1000)^2/4/pi;

Gt=GT_dB;

nochannels=ceil(BWspectrum/1000/(Dfc+GB));

