function [x,xunits,J,Junits,B,Bunits]=run_leo(xv,cv,rv,pv,xunits,cunits,runits,punits);
% run_LEO

% run LEO constellation code

% Simplifying Assumptions:
% -circular orbits only

%unpack x,c,r,p structures

C=xv.C;
r=xv.r;
epsilon=xv.epsilon;
Pt=xv.Pt;
DA=xv.DA;
Dfc=xv.Dfc;
ISL=xv.ISL;
Tsat=xv.Tsat;


MS=cv.MS;
Pe=cv.Pe;
MAM=cv.MAM;
Ge=cv.Ge;
incli=cv.incli;
eta_t=cv.eta_t;
DR=cv.DR;
GB=cv.GB;

BER=rv.BER;
R=rv.R;
margin=rv.margin;


Fms_link_lb=pv.Fms_downlink_lb;
Fms_link_ub=pv.Fms_downlink_ub;

% execute N2 Diagram in sequence

% TECHNICAL MACRO-MODULE

% 1. coverage module

if C=='polar'
   constel=1;
elseif C=='walker'
   constel=2;
else
   constel=0;
end


alti=r;   % desired orbital altitude [km]

elev=(pi/180)*epsilon;   % elevation angle [rad]


% 1. coverage module
[slantRange,dist,incli,Nmin,NSmin,NPmin,orbitR,delta,central,period] = ...
   coverage(constel,alti,elev,incli);

% 2. network module
xlink=ISL;
[GSKLOC,NGS,personnel] = satNetwork(constel,xlink,Nmin,NPmin);


% 3. spacecraft module

powerSat=Pt;  % assume sat power = transmit power
DSatT=DA;
DSatR=DSatT;
[Msat,Vsat,AntW,CEW,SCBDW,BLP,AKM,AKMDW,FSKLOC,totImpulse] = ...
   spacecraft(powerSat,DSatT,DSatR,xlink,GSKLOC);

% 4. launch vehicle module

[launchVehicle_best,LVModelFileName_best,satPerVehicle_best,...
      numberOfLaunch_best,launchSite_best,LPModelFileName_best,...
      LSla_best,LSlo_best,LSR_best,minLaunchCost,LScounter,...
      costPerLaunchl_best,costPerLaunchh_best,burnoutVelocity_best]...
   = LV(Msat,Vsat,incli,Nmin,alti);

% 5. link budget module
      route = [3,1];	% a route that goes sat->user
      if LScounter == 0 % no LV is capable of the launch
         warning('no LV is capable of the launch')
        %userPerSat = 0;
      end
        
        freqSU=0.5*(Fms_link_lb+Fms_link_ub);
        BWspectrum=(Fms_link_ub-Fms_link_lb)*1e9; % total allocated spectrum bandwidth
        GR_dB=10*log(Ge);  %user receiver gain
        userBW=R;  % single user data rate
        UpDownX=2;
        EffT=eta_t;
        EffR=EffT;
        
        [userPerSat,delaymin,delaymax,avEIRP,PFD,Gt,beamwidthT,nochannels] = linkDesign(freqSU,BWspectrum,Dfc,GB,powerSat,DSatT,GR_dB,...
           EffT,EffR,slantRange,alti,UpDownX,BER,userBW,margin,MS);
        
        delayavg=(delaymin+delaymax)/2;
        
 %   COST MACROMODULE
  
 % 6. cost module
       spaceLife=ceil(Tsat);
       IDTime=Tsat;
       [totalPresentCost,costSDAvg] = cost(Nmin,NPmin,alti,AntW,...
       CEW,SCBDW,Msat,BLP,FSKLOC,GSKLOC,spaceLife,IDTime,NGS,personnel,...
       AKM,AKMDW,totImpulse,DR,minLaunchCost);
    
 %   MARKET MACROMODULE
    
 % 7. market module
    marketSize=0.025*600e6;    %source Prentice Hall Article
     customerNumber = customer(NPmin,NSmin,incli,alti,userPerSat,marketSize,elev);

    systemCapacity = userPerSat*Nmin;
    
    syscaplife=Tsat*24*60*365*systemCapacity;
    
    cpf=totalPresentCost*1e6/syscaplife;
    
    % save results (repack output structures)
    x=xv;
    
    % objective vector
    
    J.delayavg=delayavg;                %[msec]
    J.totalcap=systemCapacity;          %[simultaneous users]
    J.syscaplife=syscaplife;            %[min]
    J.lifecyclecost=totalPresentCost;   %[M$ 2002]
    J.cpf=cpf;                          %[$/min]
    J.marketpotential=customerNumber;   %[number of subscribers]
    
    Junits.delayavg='[msec]';
    Junits.totalcap='[simultaneous users]';
    Junits.syscaplife='[lifetime min]';
    Junits.lifecyclecost='[M$ 2002]';
    Junits.cpf='[$/min]';
    Junits.marketpotential='[# of subscribers]';
    
    % benchmark variables (useful to compare with other systems)
    
    B.Nsats=Nmin;
    B.MSfreq=freqSU;
    B.Nplanes=NSmin;
    B.distance=alti;
    B.period=period;
    B.avEIRP=avEIRP;
    B.PFD=PFD;
    B.Gt=Gt;
    B.Pt=Pt;
    B.beamwidth=beamwidthT;
    B.bandwidth=BWspectrum;
    B.nochannels=nochannels;
    B.voice=R;
    B.modulation=MS;
    B.voicecircuitspersat=userPerSat;
    B.NGS=NGS;
    B.Msat=Msat;
    
    Bunits.Nsats='[# of sats]';
    Bunits.MSfreq='[GHz]';
    Bunits.Nplanes='[# of planes]';
    Bunits.distance='[km]';
    Bunits.period='[min]';
    Bunits.avEIRP='[dBW/4kHz]';
    Bunits.PFD='[Jy]';
    Bunits.Gt='[dBi]';
    Bunits.Pt='[W]';
    Bunits.beamwidth='[deg]';
    Bunits.bandwidth='[Hz]';
    Bunits.nochannels='[# of channels]';
    Bunits.voice='[kbps]';
    Bunits.modulation='[modulation]';
    Bunits.voicecircuitspersat='[# voice circuits per sat]';
    Bunits.NGS='[# ground stations]';
    Bunits.Msat='[kg]';
    
    
    save results_leo  x J B  xunits Junits Bunits
    
    %keyboard
   