% run_all reorder gives us exactly the same results as run_all but for less satellites.
% For our study, it is not important to know the lifetime of the satellites
% So we fixed the value of Tsat and reordered the way the satellites are ranked
% The altitude is reorder backwards (from 2000 to 400)
% run_all_reorder


clear all
close all

% Requirements Vector
BER=1e-3;    % bit-error-rate
R=4.8;       % data rate per channel here 4.8 kbps  (4.8 kbps for voice, 2.4 kbps data internet dialup)
margin=16;   % link (fading) margin [dB]

r.BER=BER;
r.R=R;
r.margin=margin;

runits.BER='[-]';
runits.R='[kbps]';
runits.margin='[dB]';

% Constants Vector (fixed parameters) 

MS='QPSK';            %  Modulation scheme
Pe=0.5  ;             %  [W] satellite telephone power
MAM='CDMA';           %  Multiple Access Method
Ge=1;                 %  Gain of satellite phone - NOT in dB
incli=90;    %  (max) inclination (latitude)
eta_t=55;             %  satellite transmitter efficiency in percent
DR=0;                 %  discount rate in percent
GB=2.08;              %  width of a typical guardband
Tsat=15;              %  lifetime of the system

c.MS=MS;
c.Pe=Pe; 
c.MAM=MAM;
c.Ge=Ge;
c.incli=incli;
c.eta_t=eta_t;
c.DR=DR;
c.GB=GB;
c.Tsat=Tsat;

cunits.MS='[modulation]';
cunits.Pe='[W]';
cunits.MAM='[muliple access method]';
cunits.Ge='[-]';
cunits.incli='[radians]';
cunits.eta_t='[%]';
cunits.DR='[%]';
cunits.GB='[kHz]';
cunits.Tsat='years';

Fms_uplink_lb=1.61600;  % mobile/satellite uplink frequency lower bound [GHz]
Fms_uplink_ub=1.62650;  % mobile/satellite uplink frequency upper bound [GHz]
Fms_downlink_lb=1.61600;
Fms_downlink_ub=1.62650;

p.Fms_uplink_lb=Fms_uplink_lb;
p.Fms_uplink_ub=Fms_uplink_ub;
p.Fms_downlink_lb=Fms_downlink_lb;
p.Fms_downlink_ub=Fms_downlink_ub;

punits.Fms_uplink_lb='[GHz]';
punits.Fms_uplink_ub='[GHz]';
punits.Fms_downlink_lb='[GHz]';
punits.Fms_downlink_ub='[GHz]';


% no launch vehicle restrictions

% no gateway placement/licensing restrictions


% run tradespace analysis

C='polar';    % constellation type [options: 'polar','walker']
r_all=[2000:-400:400];        % orbital altitude [km]
epsilon_all=[5:15:35];  % minimum elevation angle [deg]
Pt_all=[200:400:1800];      % satellite transmitter power [W]
DA_all=[0.5:1:3.5];       % ??? satellite antenna diameter [D] - assume parabolic not phased array
Dfc_all=[40];    % individual channel bandwidth [kHz]
ISL_all=[1 0];        % intersatellite links (1=yes, 0=no)

xunits.C='[constellation type]';
xunits.r='[km]';
xunits.epsilon='[deg]';
xunits.Pt='[W]';
xunits.DA='[m]';
xunits.Dfc='[kHz]';
xunits.ISL='[1=yes,0=no]';
xunits.Tsat='[years]';

counter=0;

hfig=waitbar(0.01,'LEO Design Space Exploration','Position',[360 514 280 60]);

for ind3=1:length(Pt_all)
    for ind4=1:length(DA_all)
        for ind5=1:length(Dfc_all)
            for ind6=1:length(ISL_all)
                   for ind2=1:length(epsilon_all)  
                       for ind1=1:length(r_all)
                           
                     counter=counter+1;
                     waitbar(counter/600,hfig);
                     
x.C=C;
x.r=r_all(ind1);
x.epsilon=epsilon_all(ind2);
x.Pt=Pt_all(ind3);
x.DA=DA_all(ind4);
x.Dfc=Dfc_all(ind5);
x.ISL=ISL_all(ind6);
x.Tsat=Tsat;


[xtmp,xunits,Jtmp,Junits,Btmp,Bunits]=run_leo(x,c,r,p,xunits,cunits,runits,punits);

x_all(:,counter)=xtmp;
J_all(:,counter)=Jtmp;
B_all(:,counter)=Btmp;

end
end
end
end
end
end
end

close(hfig)
disp('Finished Tradespace Exploration')

save LEOtradespace

for ind=1:600
   Nuser(ind)=J_all(:,ind).totalcap;
   Ctot(ind)=J_all(:,ind).syscaplife;
   LCC(ind)=J_all(:,ind).lifecyclecost;
   CPF(ind)=J_all(:,ind).cpf;
   Nsub(ind)=J_all(:,ind).marketpotential;
end

figure(1);
loglog(Ctot,LCC/1000,'b*')
hold on
loglog([2.7E11 4.5E11],[3.7 5.5],'mo')
loglog([2.05E11 5.4E11],[3.17 2.2],'gh')
xlabel('System Lifetime Capacity [min]')
ylabel('System Lifecycle Cost [B$]')

