% function spacecraft.m
% Darren Zhang (darrenz@mit.edu)
% Last modified by 3/19/02

% Using the scaling rule, this module
% takes satellite power and satellite
% antenna size as inputs and returns
% s/c mass, volume, subsystem mass,
% volume, etc.,

% problems yet to be solved:
% 1. find better correlations by riching the data
% 2. how to find antenna weight
% 3. find AKM dry weight
% 4. estimate flight software KLOC
% 5. estimate AKM total impulse
% 6. estimate the weight addition on the satellite for having crosslinks

function [Msat,Vsat,AntW,CEW,SCBDW,BLP,AKM,AKMDW,FSKLOC,totImpulse] = spacecraft(powerSat,DSatT,DSatR,xlink,GSKLOC)
if xlink == 0
    SWW = (powerSat + 176.19)/2.52 + 0.5*98.1*DSatT;		% satellite wet weight in kg, estimated from existing systems
elseif xlink == 1
    SWW = (powerSat + 176.19)/2.52 + 0.5*98.1*DSatT; % + 75;
else
    disp('xlink option error!');
end;
Msat	= SWW;		    % spacecraft mass in kg
Vsat	= SWW/156;		% spacecraft volume in m^3, estimated from existing systems
AntW	= 9.173*DSatT^1.403;	% antenna weight estimation based on Table 13-16 in SMAD
CEW		= SWW*0.27;		% communication electronics weight in kg, estimatd from existing systems
SCBDW	= SWW*0.61;		% spacecrft bus dry weight in kg, estimatd from existing systems
BLP		= 2.39*powerSat;% beginning of life power in Watts
AKM		= 2;			% type of apogee kick motor.  0 for no AKM, 1 for spin-stablized and 2 for 3-axis-stablized
                        % most LEO comm systems are 3-axis-stablized
AKMDW	= 100;  		% AKM dry weight in kg???????????
FSKLOC	= GSKLOC;		% flight software thousand lines of code????????????
totImpulse = 100000;	% AKM total impulse in kg*s?????????????
